@@ -6,7 +6,7 @@
 use v5.26;
 use Object::Pad 0.19;
 
-package Device::Chip::MPL3115A2 0.07;
+package Device::Chip::MPL3115A2 0.08;
 class Device::Chip::MPL3115A2
    extends Device::Chip::Base::RegisteredI2C;
 
@@ -18,6 +18,8 @@ use Future::AsyncAwait;
 
 use Data::Bitfield 0.02 qw( bitfield boolfield enumfield );
 
+use Device::Chip::Sensor -declare;
+
 =encoding UTF-8
 
 =head1 NAME
@@ -250,8 +252,23 @@ for the conversion to work).
 
 =cut
 
+has $_pending_trigger;
+
+declare_sensor pressure =>
+   method    => "_trigger_and_read_pressure",
+   units     => "pascals",
+   precision => 0;
+
 async method read_pressure () { return await $self->_mplread_p( REG_OUT_P_MSB ) }
 
+async method _trigger_and_read_pressure ()
+{
+   $_pending_trigger //= $self->oneshot;
+   await $_pending_trigger;
+   undef $_pending_trigger;
+   return await $self->read_pressure;
+}
+
 =head2 read_altitude
 
    $altitude = await $chip->read_altitude;
@@ -273,8 +290,21 @@ C. (The chip must I<not> be in C<RAW> mode for the conversion to work).
 
 =cut
 
+declare_sensor temperature =>
+   method    => "_trigger_and_read_temperature",
+   units     => "°C",
+   precision => 2;
+
 async method read_temperature () { return await $self->_mplread_t( REG_OUT_T_MSB ) }
 
+async method _trigger_and_read_temperature ()
+{
+   $_pending_trigger //= $self->oneshot;
+   await $_pending_trigger;
+   undef $_pending_trigger;
+   return await $self->read_temperature;
+}
+
 =head2 read_min_pressure
 
 =head2 read_max_pressure
